package com.ruoyi.abuwx.service.exam;

import com.ruoyi.abuwx.domain.exam.ExmExam;

import java.util.List;

/**
 * 考试Service接口
 * 
 * @author ruoyi
 * @date 2024-05-17
 */
public interface IExmExamService 
{
    /**
     * 查询考试
     * 
     * @param id 考试主键
     * @return 考试
     */
    public ExmExam selectExmExamById(Long id);

    /**
     * 查询考试列表
     * 
     * @param exmExam 考试
     * @return 考试集合
     */
    public List<ExmExam> selectExmExamList(ExmExam exmExam);

    /**
     * 新增考试
     * 
     * @param exmExam 考试
     * @return 结果
     */
    public int insertExmExam(ExmExam exmExam);

    /**
     * 修改考试
     * 
     * @param exmExam 考试
     * @return 结果
     */
    public int updateExmExam(ExmExam exmExam);

    /**
     * 批量删除考试
     * 
     * @param ids 需要删除的考试主键集合
     * @return 结果
     */
    public int deleteExmExamByIds(Long[] ids);

    /**
     * 删除考试信息
     * 
     * @param id 考试主键
     * @return 结果
     */
    public int deleteExmExamById(Long id);
}
